@@ -318,7 +318,7 @@ class PickleDict(DictMixin):
         #
         # The right way to solve this probably involves using the
         # hash() as the key to a second collection.
-        if not isinstance(key, basestring) or key.startswith(self.special_character):
+        if not isinstance(key, basestring) or key.startswith(self.special_character) or '/' in key:
             for filename in os.listdir(self.dir):
                 if not filename.startswith(self.special_character): continue
                 if self.key_for_path(filename) == key:
@@ -475,9 +475,12 @@ class PickleDict(DictMixin):
             return self[key]
 
         if self.log: self.logger.info('get_lazy: computing %r.' % (key,))
+        return self._compute(key, thunk, version)
+
+    def _compute(self, key, thunk, version):
         result = thunk()
         self[key] = result
-        self.set_meta(key, 'version', version)
+        self.set_meta(key, 'version', version if version is not None else 0)
         return self[key]
 
     def lazy(self, name=None, version=None):
@@ -518,14 +521,31 @@ class PickleDict(DictMixin):
         >>> answer()
         Expensive calculation...
         43
-        
+
+        You can also force a recalculation:
+
+        >>> answer()
+        43
+        >>> answer.recalculate()
+        Expensive calculation...
+        43
         '''
         from functools import wraps
         def dec(thunk): # gets called with the actual thunk
             # nonlocal name # save it for Py3.0...
             if name is None: key = thunk.__name__
             else: key = name
-            return wraps(thunk)(lambda: self.get_lazy(key, thunk, version))
+
+            @wraps(thunk)
+            def f():
+                return self.get_lazy(key, thunk, version)
+            
+            def recalculate():
+                return self._compute(key, thunk, version)
+            recalculate.__doc__ = 'Unconditionally recalculates %s, and stores and returns the result.' % key
+            f.recalculate = recalculate
+            f.func = thunk
+            return f
         return dec
 
     def lazy_dir(self, name=None):
@@ -538,8 +558,8 @@ class PickleDict(DictMixin):
                 if key in self:
                     return self[key]
                 else:
+                    res = dict(thunk())
                     pd = self.subdir(key)
-                    res = thunk()
                     pd.update(res)
                     return pd
             return f
